@@ -35,6 +35,8 @@ class TestAction(JobBase):
 
     def test(self):
         url = 'http://ip-api.com/json'
+        url = 'https://www.baidu.com'
+        # page = self.download_page(url, self.init_http_manager(default_header=True), validate_str_list=[''])
         page = self.download_page(url, self.init_http_manager(default_header=True), validate_str_list=[''])
         self._dao.save(json.loads(page))
 
